@@ -38,7 +38,7 @@ class SolarPanelConfig(BaseConfig):
     )
 
     target_solar_categories: List[str] = field(
-        default_factory=lambda: ['panel', 'cracked']
+        default_factory=lambda: ['cracked']
     )
 
     # 10: 'metal', 11: 'electronics', 12: 'can', 13: 'rod', 14: 'sunglasses'}
@@ -436,31 +436,31 @@ class SolarPanelUseCase(BaseProcessor):
         if total_solars > 0:
             # Determine event level based on thresholds
             level = "info"
-            intensity = 5.0
+            intensity = 2.0
             if config.alert_config and config.alert_config.count_thresholds:
                 threshold = config.alert_config.count_thresholds.get("all", 15)
                 intensity = min(10.0, (total_solars / threshold) * 10)
                 
-                if intensity >= 7:
+                if intensity >= 5:
                     level = "critical"
-                elif intensity >= 5:
+                elif intensity >= 2:
                     level = "warning"
                 else:
                     level = "info"
             else:
-                if total_solars > 25:
+                if total_solars > 10:
                     level = "critical"
-                    intensity = 9.0
-                elif total_solars > 15:
+                    intensity = 5.0
+                elif total_solars > 5:
                     level = "warning" 
-                    intensity = 7.0
+                    intensity = 2.0
                 else:
                     level = "info"
                     intensity = min(10.0, total_solars / 3.0)
 
             # Generate human text in new format
             human_text_lines = ["EVENTS DETECTED:"]
-            human_text_lines.append(f"\t- {total_solars} solar(s) detected [INFO]")
+            human_text_lines.append(f"\t- {total_solars} crack(s) detected [INFO]")
             human_text = "\n".join(human_text_lines)
 
             event = {
@@ -483,25 +483,25 @@ class SolarPanelUseCase(BaseProcessor):
         # Add alert events
         for alert in alerts:
             total_solars = counting_summary.get("total_count", 0)
-            intensity_message = "ALERT: Low solar in the scene"
+            intensity_message = "ALERT: Low crack in the scene"
             if config.alert_config and config.alert_config.count_thresholds:
                 threshold = config.alert_config.count_thresholds.get("all", 15)
                 percentage = (total_solars / threshold) * 100 if threshold > 0 else 0
                 if percentage < 20:
-                    intensity_message = "ALERT: Low solar in the scene"
+                    intensity_message = "ALERT: Low crack in the scene"
                 elif percentage <= 50:
-                    intensity_message = "ALERT: Moderate solar in the scene"
+                    intensity_message = "ALERT: Moderate crack in the scene"
                 elif percentage <= 70:
-                    intensity_message = "ALERT: Heavy solar in the scene"
+                    intensity_message = "ALERT: Heavy crack in the scene"
                 else:
-                    intensity_message = "ALERT: Severe solar in the scene"
+                    intensity_message = "ALERT: Severe crack in the scene"
             else:
                 if total_solars > 15:
-                    intensity_message = "ALERT: Heavy solar in the scene"
+                    intensity_message = "ALERT: Heavy crack in the scene"
                 elif total_solars == 1:
-                    intensity_message = "ALERT: Low solar in the scene"
+                    intensity_message = "ALERT: Low crack in the scene"
                 else:
-                    intensity_message = "ALERT: Moderate solar in the scene"
+                    intensity_message = "ALERT: Moderate crack in the scene"
 
             alert_event = {
                 "type": alert.get("type", "congestion_alert"),
@@ -563,13 +563,13 @@ class SolarPanelUseCase(BaseProcessor):
                 solars_text = f"\t{', '.join(category_counts[:-1])}, and {category_counts[-1]} detected"
             human_text_lines.append(f"\t- {solars_text}")
         else:
-            human_text_lines.append(f"\t- No solars detected")
+            human_text_lines.append(f"\t- No cracks detected")
 
         human_text_lines.append("")  # spacing
 
         # TOTAL SINCE section
         human_text_lines.append(f"TOTAL SINCE {start_timestamp}:")
-        human_text_lines.append(f"\t- Total solars Detected: {cumulative_total}")
+        human_text_lines.append(f"\t- Total cracks Detected: {cumulative_total}")
         # Add category-wise solar counts
         if total_solar_counts:
             for cat, count in total_solar_counts.items():
@@ -635,9 +635,9 @@ class SolarPanelUseCase(BaseProcessor):
         total_solars = summary.get("total_count", 0)
 
         if total_solars == 0:
-            insights.append("No solars detected in the scene")
+            insights.append("No cracks detected in the scene")
             return insights
-        insights.append(f"EVENT: Detected {total_solars} solars in the scene")
+        insights.append(f"EVENT: Detected {total_solars} cracks in the scene")
         # Intensity calculation based on threshold percentage
         intensity_threshold = None
         if (config.alert_config and 
@@ -650,13 +650,13 @@ class SolarPanelUseCase(BaseProcessor):
             percentage = (total_solars / intensity_threshold) * 100
             
             if percentage < 20:
-                insights.append(f"INTENSITY: Low solar in the scene ({percentage:.1f}% of capacity)")
+                insights.append(f"INTENSITY: Low crack in the scene ({percentage:.1f}% of capacity)")
             elif percentage <= 50:
-                insights.append(f"INTENSITY: Moderate solar in the scene ({percentage:.1f}% of capacity)")
+                insights.append(f"INTENSITY: Moderate crack in the scene ({percentage:.1f}% of capacity)")
             elif percentage <= 70:
-                insights.append(f"INTENSITY:  Heavy solar in the scene ({percentage:.1f}% of capacity)")
+                insights.append(f"INTENSITY:  Heavy crack in the scene ({percentage:.1f}% of capacity)")
             else:
-                insights.append(f"INTENSITY: Severe solar in the scene ({percentage:.1f}% of capacity)")
+                insights.append(f"INTENSITY: Severe crack in the scene ({percentage:.1f}% of capacity)")
         # else:
         #     # Fallback to hardcoded thresholds if no alert config is set
         #     if total_solars > 15:
@@ -681,11 +681,11 @@ class SolarPanelUseCase(BaseProcessor):
             for category, threshold in config.alert_config.count_thresholds.items():
                 if category == "all" and total >= threshold:
                     timestamp = datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC')
-                    alert_description = f"solars count ({total}) exceeds threshold ({threshold})"
+                    alert_description = f"Cracks count ({total}) exceeds threshold ({threshold})"
                     alerts.append({
                         "type": "count_threshold",
                         "severity": "warning",
-                        "message": f"Total solar count ({total}) exceeds threshold ({threshold})",
+                        "message": f"Total crack count ({total}) exceeds threshold ({threshold})",
                         "category": category,
                         "current_count": total,
                         "threshold": threshold
@@ -728,14 +728,14 @@ class SolarPanelUseCase(BaseProcessor):
         cumulative_total = sum(cumulative.values()) if cumulative else 0
         lines = []
         if total > 0:
-            lines.append(f"{total} solar(s) detected")
+            lines.append(f"{total} crack(s) detected")
             if per_cat:
                 lines.append("solars:")
                 for cat, count in per_cat.items():
                     lines.append(f"\t{cat}:{count}")
         else:
-            lines.append("No solar detected")
-        lines.append(f"Total solars detected: {cumulative_total}")
+            lines.append("No crack detected")
+        lines.append(f"Total cracks detected: {cumulative_total}")
         if alerts:
             lines.append(f"{len(alerts)} alert(s)")
         return "\n".join(lines)
